=============
Asset Manager
=============

Asset Manager is a Django library that provides a way to manage assets like
images in a centralized way.

Installation
------------

.. code-block:: sh

    $ pip install fh-django-assetmanager

Running tests
-------------

TODO

Usage
-----

TODO